@@ -20,24 +20,27 @@
 #'
 #' icc.de(prof1 = c(-1, -0.85, 2), prof2 = c(-0.93, 1, 1.26), input = "score",
 #' digits = 4)
-#'
+
 icc.de <- function(prof1, prof2, input = c("cor", "score"), digits = 2){
 
+  if(length(prof1) != length(prof2)){
+    warning("The profiles have different lengths. Please double-check!")}
+
   choice <- match.arg(input)
   input.kind <- switch(choice, cor = 1, score = 2)
 
   if(input.kind == 1){
     x.cor <- atanh(prof1);
     y.cor <- atanh(prof2);
-    xy <- c(x.cor, y.cor);
-    yx <- c(y.cor, x.cor)
+    xy <- c(x.cor, rev(y.cor));
+    yx <- c(y.cor, rev(x.cor))
     }
 
   if(input.kind == 2){
-    xy <- c(prof1, prof2);
-    yx <- c(prof2, prof1)
+    xy <- c(prof1, rev(prof2));
+    yx <- c(prof2, rev(prof1))
     }
 
-  iccde <- round(cor(xy, yx, use = "pairwise"), digits);
+  iccde <- round(cor(xy, yx), digits);
   return(iccde)
 }
